@@ -43,8 +43,8 @@ class SystemDesign(object):
     ac_capacity: float
     poi_limit: float
     gcr: float
-    modules_per_string: int
-    strings_in_parallel: int
+    modules_per_string: t.Optional[int]
+    strings_in_parallel: t.Optional[int]
     tracking: t.Union[FixedTilt, SingleAxisTracking]
     azimuth: t.Optional[float] = opt_field()
 
@@ -88,7 +88,7 @@ class PVModule(object):
     gamma_r: float
     bifacial_transmission_factor: float
     bifaciality: float
-    bifacial_ground_clerance_height: float
+    bifacial_ground_clearance_height: float
 
 @dataclass_json
 @dataclass
